==> mfe-ai-2.0-20160710.162547-7-sources.jar: net/zomis/minesweeper/ais/AI_Nightmare.java <==
package net.zomis.minesweeper.ais;

import net.zomis.minesweeper.ais.post.BombStifle;
import net.zomis.minesweeper.ais.post.ChickenPlayCounter;
import net.zomis.minesweeper.aiscore.AvoidReveal50_New;
import net.zomis.minesweeper.aiscore.BombIfManyMinesScorer;
import net.zomis.minesweeper.aiscore.BombScore;
import net.zomis.minesweeper.aiscore.CertainMines;
import net.zomis.minesweeper.aiscore.NonRevealingSafeClicks;
import net.zomis.minesweeper.aiscore.OpenFieldsPenalty;
import net.zomis.minesweeper.aiscore.SafeOpenField;
import net.zomis.minesweeper.aiscore.SafeProbabilityAroundMine;
import net.zomis.minesweeper.aiscore.SafeWithRiskAroundMine;
import net.zomis.minesweeper.aiscore.UnevenProbabilities;
import net.zomis.minesweeper.aiscore.mario.RealMarioEV1;
import net.zomis.minesweeper.aiscore.mario.RealMarioEVScorer;
import net.zomis.minesweeper.api.Invite;
import net.zomis.minesweeper.api.ai.AISupplier;
import net.zomis.minesweeper.api.ai.MinesweeperAI;
import net.zomis.minesweeper.game.MinesweeperMove;
import net.zomis.minesweeper.game.MinesweeperPlayingPlayer;
import net.zomis.minesweeper.scores.AnalyzeMethod;
import net.zomis.minesweeper.scores.ScoreConfigFactory;

// @AI(rating = 3200)
public class AI_Nightmare extends AI_Zomis {

	public static final AISupplier PROVIDER = new StaticAISupplier(new AI_Nightmare());

	public AI_Nightmare() {
		super("#AI_Nightmare", new ScoreConfigFactory(AnalyzeMethod.ZOMIS_ADVANCED)
				.withPreScorer(new MarioAnalyze())
				
				// Click scorers
				.withScorer(new NonRevealingSafeClicks())
				.withScorer(new CertainMines())
				.withScorer(new OpenFieldsPenalty())
				.withScorer(new SafeProbabilityAroundMine())
				.withScorer(new SafeWithRiskAroundMine())
				
				.withScorer(new RealMarioEVScorer())
				.withScorer(new SafeOpenField())
				.withScorer(new RealMarioEV1())
				
				.withScorer(new UnevenProbabilities())
				.withScorer(new AvoidReveal50_New())
				.withScorer(new OptimizeMyBomb())
				
				// Bomb scorers
				.withScorer(new BombScore())
				.withScorer(new BombIfManyMinesScorer(9.0 / 51.0))
				
				.withPost(new ChickenPlayCounter())
				.withPost(new BombStifle())
				.build()
			);
		this.setBackup(new AISupplier() {
			@Override
			public MinesweeperAI get(MinesweeperPlayingPlayer player) {
				return new AI_Extreme3();
			}
		});
	}

	@Override
	public MinesweeperMove play(MinesweeperPlayingPlayer pp) {
		return this.playWithDrawproposal(pp);
	}
	
	@Override
	public boolean respondToInvite(Invite invite) {
		if (invite.getPlayers().size() > 2) {
			invite.getHost().sendAlert(this.getName() + ": Unfortunately, I am not built to play other than 2 player games.");
			return false;
		}
		return super.respondToInvite(invite);
	}


}

==> mfe-ai-2.0-20160710.185141-8-sources.jar: net/zomis/minesweeper/ais/AI_Nightmare.java <==
package net.zomis.minesweeper.ais;

import net.zomis.minesweeper.ais.post.BombStifle;
import net.zomis.minesweeper.ais.post.ChickenPlayCounter;
import net.zomis.minesweeper.aiscore.AvoidReveal50_New;
import net.zomis.minesweeper.aiscore.BombIfManyMinesScorer;
import net.zomis.minesweeper.aiscore.BombScore;
import net.zomis.minesweeper.aiscore.CertainMines;
import net.zomis.minesweeper.aiscore.NonRevealingSafeClicks;
import net.zomis.minesweeper.aiscore.OpenFieldsPenalty;
import net.zomis.minesweeper.aiscore.SafeOpenField;
import net.zomis.minesweeper.aiscore.SafeProbabilityAroundMine;
import net.zomis.minesweeper.aiscore.SafeWithRiskAroundMine;
import net.zomis.minesweeper.aiscore.UnevenProbabilities;
import net.zomis.minesweeper.aiscore.mario.RealMarioEV1;
import net.zomis.minesweeper.aiscore.mario.RealMarioEVScorer;
import net.zomis.minesweeper.analyze.InterruptCheck;
import net.zomis.minesweeper.api.Invite;
import net.zomis.minesweeper.api.ai.AISupplier;
import net.zomis.minesweeper.api.ai.MinesweeperAI;
import net.zomis.minesweeper.game.MinesweeperMove;
import net.zomis.minesweeper.game.MinesweeperPlayingPlayer;
import net.zomis.minesweeper.scores.AnalyzeMethod;
import net.zomis.minesweeper.scores.ScoreConfigFactory;

// @AI(rating = 3200)
public class AI_Nightmare extends AI_Zomis {

	public AI_Nightmare(InterruptCheck interruptCheck) {
		super("#AI_Nightmare", new ScoreConfigFactory(AnalyzeMethod.ZOMIS_ADVANCED)
				.withPreScorer(new MarioAnalyze(interruptCheck))
				
				// Click scorers
				.withScorer(new NonRevealingSafeClicks())
				.withScorer(new CertainMines())
				.withScorer(new OpenFieldsPenalty())
				.withScorer(new SafeProbabilityAroundMine())
				.withScorer(new SafeWithRiskAroundMine())
				
				.withScorer(new RealMarioEVScorer())
				.withScorer(new SafeOpenField())
				.withScorer(new RealMarioEV1())
				
				.withScorer(new UnevenProbabilities())
				.withScorer(new AvoidReveal50_New())
				.withScorer(new OptimizeMyBomb())
				
				// Bomb scorers
				.withScorer(new BombScore())
				.withScorer(new BombIfManyMinesScorer(9.0 / 51.0))
				
				.withPost(new ChickenPlayCounter())
				.withPost(new BombStifle())
				.build()
			);
		this.setBackup(new AISupplier() {
			@Override
			public MinesweeperAI get(MinesweeperPlayingPlayer player) {
				return new AI_Extreme3();
			}
		});
	}

	@Override
	public MinesweeperMove play(MinesweeperPlayingPlayer pp) {
		return this.playWithDrawproposal(pp);
	}
	
	@Override
	public boolean respondToInvite(Invite invite) {
		if (invite.getPlayers().size() > 2) {
			invite.getHost().sendAlert(this.getName() + ": Unfortunately, I am not built to play other than 2 player games.");
			return false;
		}
		return super.respondToInvite(invite);
	}


}
